OiRA

Help

1. Příprava
2. Zapojení
3. Vyhledání rizik + Hodnocení rizik
4. Akční plán
5. Zpráva
6. Status 0%

# Přizpůsobení vyhodnocení rizik vaší organizaci

Aby bylo možno přizpůsobit vyhodnocení rizik vaší organizaci, můžete být požádán/a o:

- zvolte nebo přeskočte situaci/situace, které souvisejí či nikoliv s vaší obchodní činností, a zatrhněte příslušné/á políčko/a
- uvést kolektivní obchodní jednotky, pobočky nebo obchody atd. Tato související rizika se budou opakovat pro každé jméno, které zadáte.

## Commercial manned guarding

Does your organisation provide commercial manned guarding? Yes No
Do you offer this service in multiple locations? Yes No
Please enter a name for the location you would like to assess. Please enter the name for each location you would like to assess.

## Mobile partrolling/intervention after alarm

Does your organisation provide mobile patrolling / intervention after alarm? Yes No
Do you offer this service in multiple locations? Yes No
Please enter a name for the location you would like to assess. Please enter the name for each location you would like to assess.

## Event security

Does your organisation provide event security? Yes No
Do you offer this service in multiple locations? Yes No
Please enter a name for the location you would like to assess. Please enter the name for each location you would like to assess.

Scroll to top
Back

## profiling.html

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More